crawler

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Crawler

type Crawler struct {
	// contains filtered or unexported fields
}

Crawler represents a web crawler that generates random HTTP traffic

func NewCrawler

func NewCrawler(cfg *config.Config) *Crawler

NewCrawler creates a new crawler with the given configuration

func (*Crawler) Crawl

func (c *Crawler) Crawl()

Crawl starts the crawling process

Jump to